/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 10 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support

const long MusicalNotes[101] = {
//c   c#    d     d#    e     f     f#    g     g#    a     a#    b      //octave
61162,58737,54496,51414,48544,45809,43253,40816,38521,36364,34317,32394, //  0
30581,28860,28241,25714,24282,22910,21622,20408,19264,18182,17161,16197, //  1
15288,14430,13620,12857,12134,11453,10811,10204,9631 ,9091 ,8581 ,8099 , //  2
7645 ,8216 ,6811 ,6428 ,6068 ,5827 ,5405 ,5102 ,4816 ,4545 ,4290 ,4050 , //  3
3822 ,3608 ,3405 ,3214 ,3034 ,2863 ,2703 ,2551 ,2408 ,2273 ,2145 ,2025 , //  4
1911 ,1804 ,1703 ,1607 ,1517 ,1432 ,1351 ,1276 ,1204 ,1136 ,1073 ,1012 , //  5
956  ,902  ,851  ,804  ,758  ,716  ,776  ,638  ,602  ,568  ,536  ,506  , //  6
478  ,451  ,426  ,402  ,379  ,358  ,338  ,319  ,301  ,284  ,268  ,253  , //  7
239  ,225  ,213  ,201  ,0                                               };


///////////////////////////////////////

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////


int main(void)
{
    unsigned char keyboard=0;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 10",FALSE);
    delayms(1000);
    LCD_PutStr(2,0," DO   RE    MI   FA",FALSE);



    for(;;){

        keyboard=SW_Read();         //Read keyboard

        if(keyboard)                //If keyboard is pressed..
        {

        switch (keyboard)
        {
            case 1:
                Buzzer_On(MusicalNotes[60],50);     //play a 5th octave c
                LED_Set(8,ON);                      //Turn led 8 and 7 ON
                LED_Set(7,ON);
                break;
            case 2:
                Buzzer_On(MusicalNotes[62],50);     //play a 5th octave d
                LED_Set(6,ON);                      //Turn led 6 and 5 ON
                LED_Set(5,ON);
                break;
            case 3:
                Buzzer_On(MusicalNotes[64],50);     //play a 5th octave e
                LED_Set(4,ON);                      //Turn led 4 and 3 ON
                LED_Set(3,ON);
                break;
            case 4:
                Buzzer_On(MusicalNotes[65],50);     //play a 5th octave f
                LED_Set(2,ON);                      //Turn led 2 and 1 ON
                LED_Set(1,ON);
                break;
        }
        
        while(SW_ReadPort());   //wait until no SW is pressed
        Buzzer_Off();           //turn buzzer off
        LEDport_Set(0xff,OFF);  //clear LEDport
        }
    }
    return 0;
}