/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 13 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support


///////////////////////////////////////


void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////


int main(void)
{
    unsigned char keyboard=0;
    char lcdMSG[20] = {'F','o','l','l','o','w','s',' ','y','o','u','r',' ','t','e','x','t','.','.',0};
    int i;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 13",FALSE);

    for(;;){

        keyboard=SW_Read();             //Read Keyboard

        if(keyboard==1)
        {
            LCD_PutStr(1,0,"Blinking Cursor",TRUE);         //Write "Blinking..."
            LCD_GotoYX(2,0);                                //LCD goto Y2, X0
            LCD_SetCursorBlink(TRUE);                       //LCD CursorBlink ON
            delayms(1000);
            
            for(i=0 ; i<19 ; i++){
                    LCD_Putc(lcdMSG[i]);                    //Character i of lcdMSG
                delayms(80);
            }
        }

    }
    return 0;
}