/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 14 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support

/* Custom chars */
unsigned char customChar1[] = {             //Create Custom Character 1
    0b00100,
    0b00100,
    0b11111,
    0b00000,
    0b01110,
    0b10101,
    0b00100,
    0b00100
};

unsigned char customChar2[] = {             //Create Custom Character 2 
    0X04,
    0X04,
    0X1F,
    0X0E,
    0X04,
    0X1F,
    0X04,
    0X04
};

unsigned char customChar3[] = {             //Create Custom Character 3
    0x00,
    0x00,
    0x0E,
    0x11,
    0x11,
    0x0A,
    0x1B,
    0x00
};

unsigned char customChar4[] = {             //Create Custom Character 4
    0x1F,
    0X00,
    0x04,
    0x0E,
    0x0E,
    0x1F,
    0x00,
    0x04,
};

unsigned char customChar5[] = {             //Create Custom Character 5
    0x04,
    0x0A,
    0x15,
    0x15,
    0x17,
    0x11,
    0x0A,
    0x04,
};

unsigned char customChar6[] = {             //Create Custom Character 6
    0x00,
    0x0A,
    0x0A,
    0x0A,
    0x00,
    0x11,
    0x0E,
    0x00
};

unsigned char customChar7[] = {             //Create Custom Character 7
    0x04,
    0x02,
    0x09,
    0x05,
    0x15,
    0x05,
    0x09,
    0x02,
};

unsigned char customChar8[] = {             //Create Custom Character 8
    0x01,
    0x01,
    0x05,
    0x06,
    0x1C,
    0x06,
    0x05,
    0x01,
};

///////////////////////////////////////


void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////


int main(void)
{

    int keyboard;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 14",FALSE);

        LCD_StoreCustomChar(customChar1,0);             //Store custom char in CGRAM location 0
        LCD_StoreCustomChar(customChar2,1);             //Store custom char in CGRAM location 1
        LCD_StoreCustomChar(customChar3,2);
        LCD_StoreCustomChar(customChar4,3);
        LCD_StoreCustomChar(customChar5,4);
        LCD_StoreCustomChar(customChar6,5);
        LCD_StoreCustomChar(customChar7,6);
        LCD_StoreCustomChar(customChar8,7);

    for(;;){
        
        keyboard=SW_Read();
        
        if(keyboard==1)
        {
            
        LCD_PutStr(1,0,"Store 8 custom chars",TRUE);    //Write "Store 8..."
            
        LCD_GotoYX(2,5);                            //LCD goto Y2, X5
        LCD_PutCustomChar(0);                   //Put Custom Char 0                         
        LCD_PutCustomChar(1);                   //Put Custom Char 1
        LCD_PutCustomChar(2);
        LCD_PutCustomChar(3);
        LCD_PutCustomChar(4);
        LCD_PutCustomChar(5);
        LCD_PutCustomChar(6);
        LCD_PutCustomChar(7);
        }

    }
    return 0;
}