 /********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 14 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support
#include "timers.h"             //Timers support

unsigned int u_sec;         //Microseconds
unsigned char  sec;         //Seconds
unsigned char  min;         //Minutes

    /*Timer 1 interrupt service routine*/
void __attribute__((__interrupt__, __shadow__,__no_auto_psv__)) _T1Interrupt(void)
{
    u_sec++;
    if (u_sec>=99){
        u_sec=0;
        sec++;
    }
    if (sec>=59){
        sec=0;
        min++;
    }
    if (min>=59){
        min=0;
    }

    IFS0bits.T1IF = 0; //Reset Timer1 interrupt flag and Return from ISR
}

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

    /*Timers*/
    Timer1_Init();
    Timer1_SetTick(TIMER_TICK_10MS);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////

int main(void)
{
    unsigned char keyboard=0;
    char lcdMSG[20];
    BOOL mode = FALSE;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 14",FALSE);
    delayms(1000);
    LCD_PutStr(2,0,"Start Stop Reset BIG",TRUE);

    for(;;){

        keyboard=SW_Read();         //Read keyboard

        switch (keyboard)
        {
            case 1:
                Timer1_Enable();        //Enable Timer 1
                break;
            case 2:
                Timer1_Disable();       //Disable Timer 1
                break;
            case 3:
                Timer1_Disable();       //Disable Timer 1
                u_sec=0;
                sec=0;
                min=0;
                break;
            case 4:
                if (mode) {
                    LCD_Init(LCD_MODE_1);       //Lcd double line
                    mode=FALSE;
                }
                else {
                    LCD_Init(LCD_MODE_2);       //Lcd double height
                    mode=TRUE;
                }
                break;
        }

        sprintf(lcdMSG,"%.2u:%.2u.%.2u",min,sec,u_sec);     //Create string
        LCD_PutStr(1,6,lcdMSG,FALSE);                       //Write lcdMSG
        LCD_PutStr(2,0,"Start Stop Reset BIG",FALSE);

    }
    return 0;
}

