/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 16 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support
#include "timers.h"
#include "realtime.h"             //Timers support

unsigned char  sec;         //Seconds
unsigned char  min;         //Minutes
unsigned char  hour;         //Minutes

    /*Timer 1 interrupt service routine*/
void __attribute__ ((interrupt,no_auto_psv)) _RTCCInterrupt(void)
{
    sec++;
    if (sec>=60){
        sec=0;
        min++;
    }
    if (min>=60){
        min=0;
        hour++;
    }
    if (hour>=24){
        hour=0;
    }

    IFS3bits.RTCIF = 0;  //clear the interrupt status
}

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

    /*RTCC*/
    RTCC_Init();

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////

int main(void)
{
    unsigned char keyboard=0;
    char lcdMSG[20];
    BOOL mode = FALSE;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 16",FALSE);
    delayms(1000);
    LCD_PutStr(2,0,"Start Stop Reset BIG",TRUE);

    for(;;){

        keyboard=SW_Read();         //Read keyboard

        switch (keyboard)
        {
            case 1:
                RTCC_Enable();        //Enable RTCC
                break;
            case 2:
                RTCC_Disable();       //Disable RTCC
                break;
            case 3:
                RTCC_Disable();       //Disable RTCC
                sec=0;
                min=0;
                hour=0;
                break;
            case 4:
                if (mode) {
                    LCD_Init(LCD_MODE_1);       //Lcd double line
                    mode=FALSE;
                }
                else {
                    LCD_Init(LCD_MODE_2);       //Lcd double height
                    mode=TRUE;
                }
                break;
        }

        sprintf(lcdMSG,"%.2u:%.2u.%.2u",hour,min,sec);     //Create string
        LCD_PutStr(1,6,lcdMSG,FALSE);                       //Write lcdMSG
        LCD_PutStr(2,0,"Start Stop Reset BIG",FALSE);

    }
    return 0;
}