/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 17 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support
#include "string.h"             //Strings support


///////////////////////////////////////

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////

//returns a formatted string
const char *byte_to_binary(int x)
{
    static char b[9];
    b[0] = '\0';

    int z;
    for (z = 128; z > 0; z >>= 1)
    {
        strcat(b, ((x & z) == z) ? "1" : "0");
    }

    return b;
}

int main(void)
{
    unsigned char DIPvalue=0;
    char lcdMSG[20];

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 17",FALSE);
    delayms(1000);

    for(;;){

        //read DIPsw and store it in DIPvalue var
        DIPvalue = DIPSW_Read();

        //create a string with sprintf() and displayit in Y1 X0
        sprintf(lcdMSG,"DEC: %u, HEX: %.2X",DIPvalue,DIPvalue);
        LCD_PutStr(1,0,lcdMSG,TRUE);    //display it on Y1X0

        //Using sprintf() and byte_to_binary(),create a string for the LCD
        sprintf(lcdMSG,"BIN: %s",byte_to_binary(DIPvalue));
        LCD_PutStr(2,0,lcdMSG,FALSE);


        LEDport_Set(DIPvalue,ON);       //set the LEDport
        
        delayms(150);                   //Delay 150 milliseconds
        
    }
    return 0;
}