/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 19 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "RS232.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support

#define max_temp 25
#define min_temp 10

///////////////////////////////////////

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////


int main(void)
{
    char lcdMSG1[20],lcdMSG2[20];
    int temp;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 19",FALSE);

    delayms(1000);
    for(;;){

        temp=ADC_Range(-20,60);             //Read ADC input

        if(temp>=max_temp)                  //If temp is greater than max temp
        {                                   //Then..
            RLY_Set(1,ON);                  //Turn it ON
        }
        else
        {
            RLY_Set(1,OFF);                 //Turn it OFF
        }
        if(temp<=min_temp)                  //If temp is less than max temp
        {                                   //Then..
            OC_Set(1,ON);                   //Turn it ON
        }
        else
        {
            OC_Set(1,OFF);                  //Turn it OFF
        }

        //Create a strings for the LCD
        sprintf(lcdMSG1,"Temperatura =%1i",temp);
        sprintf(lcdMSG2,"Temp Max %1i Min %1i",max_temp,min_temp);

        //Display it in (y1,x0) and (y2,x0)
        LCD_PutStr(1,0,lcdMSG1,TRUE);
        LCD_PutStr(2,0,lcdMSG2,FALSE);
        
        delayms(150);                       //Delay 150 milliseconds
    }
    return 0;
}
