/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 20 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support


///////////////////////////////////////

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////


int main(void)
{

    char lcdMSG[20];
    int i;

    HammerHead_Init();              //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",ON);
    LCD_PutStr(2,0,"Application Note 20",OFF);
    delayms(500);
    LCD_Clear();

    for(;;)
    {
        //Create a strings for the LCD//
        LCD_PutStr(1,0,"Presione un boton",FALSE);
        WDOG_SoftEnable();                          //WDOG Timer Enable

        if(DIPSW_Read()==1)                         //If DIP SW is 1
        {                                           //Then...
            WDOG_SoftDisable();                     //WDOG Timer Disable
        }

        if(SW_ReadPort())                           //If SW Port is true.
        {                                           //Then...
            for(i=0;i<=10;i++)                      //Counting from 0 to 10
            {
                WDOG_Pet();                         //Refresh the watchdog counter
                //Create a strings for the LCD//
                sprintf(lcdMSG,"TIME = %i",i);
                LCD_PutStr(1,0,lcdMSG,TRUE);
                delayms(250);                       //Delay 250 milliseconds
            }
        }

    }
    return 0;
}