/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 21 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support

int i=128;
BOOL Direction=ON;

void LED_sequence(void)
{
    if(Direction)
    {
        i>>=1;
        Direction=(i==1) ? OFF : ON;
    }
    else
    {
        i<<=1;
        Direction=(i==128) ? ON: OFF;
    }
}
///////////////////////////////////////

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////


int main(void)
{

    const char Active =0b1001;                 //Active value is 9 (1001)

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 21",FALSE);
    delayms(500);
    LCD_Clear();

    for(;;){

        //Create a strings for the LCD//
        LCD_PutStr(1,0,"DESACTIVADO",FALSE);

        while (IN_ReadPort()==Active)          //While IN_Read Port is 9 (1001)
        {
            //Create a strings for the LCD//
            LCD_PutStr(1,0,"ACTIVADO",TRUE);
            LED_sequence();                     // Initialize LED _sequence
            LEDport_Set(i,ON);                  //Show i value in LEDport
            delayms(250);                       //Delay 250 milliseconds
        }
    }
    return 0;
}