/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 22 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support

#define CALIBRATION_VALUE 298

///////////////////////////////////////

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////


int main(void)
{
    char lcdMSG1[20];
    float ADCvalue;
    unsigned int Pretemp;
    int Temp_cent, Temp_fahr;

    HammerHead_Init();              //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",ON);
    LCD_PutStr(2,0,"Application Note 22",OFF);


    for(;;)
    {

        ADCvalue=(ADC_Read()*3.3)/1018;         //Read ADC & convert in Volts
        Pretemp=(ADCvalue*100);                 //Convert Volts in Millivolts

        //If millivolts is greater than Calibration Value//
        if(Pretemp>=CALIBRATION_VALUE)
        {
            Temp_cent=25+(Pretemp-CALIBRATION_VALUE);       //Set new temperature
        }
        //If millivolts is less than Calibration Value//
        if(Pretemp<CALIBRATION_VALUE)
        {
            Temp_cent=25-(CALIBRATION_VALUE-Pretemp);       //Set new temperature
        }

        Temp_fahr=((Temp_cent*9)/5)+32;          //Convert centigrades of fahrenheit

        //Create a strings for the LCD//
        sprintf(lcdMSG1,"TEMP = %i\xDF\x43   %i\xDF\x46",Temp_cent,Temp_fahr);
        LCD_PutStr(1,0,lcdMSG1,TRUE);
        delayms(250);                           //Delay 250 milliseconds
    }
    return 0;
}