/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 23 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //Analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //Output support
#include "inputs.h"             //Inputs support
#include "stepper.h"            //Stepper support


///////////////////////////////////////

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////


int main(void)
{
    unsigned char keyboard=0;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 23",FALSE);

    for(;;){

        keyboard=SW_Read();         //Read keyboard

        switch (keyboard)
        {
            case 1:
                    //Create a strings for the LCD//
                LCD_PutStr(1,0,"15 Half step",TRUE);
                
                Unipolar_Set(MODE_HALF_STEP,48,SPEED_MOTOR_4);  /*Setting motor*/
                Steps(15);      //Move 15 Steps
                break;
            case 2:
                    //Create a strings for the LCD//
                LCD_PutStr(1,0,"-15 Simple step",TRUE);

                Unipolar_Set(MODE_SIMPLE_STEP,48,SPEED_MOTOR_4);    /*Setting motor*/
                Steps(-15);     //Move -15 Steps
                break;
            case 3:
                    //Create a strings for the LCD//
                LCD_PutStr(1,0,"180\xDF Speed max",TRUE);

                Unipolar_Set(MODE_SIMPLE_STEP,48,SPEED_MOTOR_MAX);  /*Setting motor*/
                Degrees(180);   //Move 180 degrees
                break;
            case 4:
                 //Create a strings for the LCD//
                LCD_PutStr(1,0,"-90\xDF ",TRUE);
                
                Degrees(-90);   //Move -180 degrees
                break;
        }
    }
    return 0;
}