/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrón Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 26 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "EEPROM.h"             //EEPROM support
#include "IO.h"                 //IO support
#include "inputs.h"             //inputs support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "realtime.h"           //RTCC module support
#include "RS232.h"              //RS232 support
#include "timers.h"             //timers support

//USB Support//
#include "USB/usb.h"
#include "USB/usb_host_msd.h"
#include "USB/usb_host_msd_scsi.h"
#include "MDD File System/FSIO.h"


///////////////////////////////////////

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    DIPSW_Config(DIPSW_DISABLE_CMD);
    ADC_Init();

    /*UART*/
    RS232_Init(BAUD9600);  //set 9600bps as UART speed

    /*LCD*/
    LCD_Init(LCD_MODE_1);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif

    /*RTCC*/
    RTCC_Init();    //interurpt is handled within realtime.c
    RTCC_Enable();

    /*timers*/
    Timer1_Init();
    Timer1_SetTick(TIMER_TICK_50MS);
    Timer1_Enable();        //interurpt is handled within timers.c

    Timer4_Init();
    Timer4_SetTick(TIMER_TICK_100MS);
    Timer4_Enable();        //interurpt is handled within timers.c

    LEDport_Set(0,ON);
}

void InsertChime(void)
{
    delayms(100);
    Buzzer_On(800,50);
    delayms(30);
    Buzzer_Off();
    delayms(80);
    Buzzer_On(421,50);
    delayms(30);
    Buzzer_Off();
}

void RemoveChime(void)
{
    delayms(100);
    Buzzer_On(421,50);
    delayms(30);
    Buzzer_Off();
    delayms(80);
    Buzzer_On(800,50);
    delayms(30);
    Buzzer_Off();
}

///////////////////////////////////////

int main(void)
{

    FSFILE * myFile;
    char  lcdMSG[20] , fileMSG[22];
    int   ADCvalue =0 , i=0;

    HammerHead_Init();  //initialize [VD]HammerHead

    USBInitialize(0);   //Initialize the stack
    USB_5V_ENABLE = 0;  //Turn 5V USB output on

    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 26",FALSE);
    delayms(1000);
    LCD_PutStr(1,0,"Aguijon USB MSD",TRUE);
    LCD_PutStr(2,0,"Insert flash drive",FALSE);

    for(;;){
        //USB stack process function
        USBTasks();

        //if thumbdrive is plugged in
        if(USBHostMSDSCSIMediaDetect()){
            InsertChime();
            //now a device is attached

            //See if the device is attached and in the right format
            if(FSInit()){

                LCD_PutStr(1,0,"Start measurements",TRUE);

                //Opening a file in mode "a"
                myFile = FSfopen("test.csv","a");
                delayms(500);                       //Delay 500 milliseconds

                //Write some data to the new file.
                FSfwrite("\x0D Measuring number,Value",1,25,myFile);

                for(i=1;i<=10;i++)
                {
                    ADCvalue=ADC_Range(0,100);      //Read ADC port

                    //Create a strings for the LCD//
                    sprintf(lcdMSG,"Measurement# %i =%i",i,ADCvalue);
                    LCD_PutStr(1,0,lcdMSG,TRUE);

                    //Create a strings for the FILE//
                    sprintf(fileMSG,"\x0D Measurement# %i ,%i ",i,ADCvalue);
                    FSfwrite(fileMSG,1,22,myFile);
                    delayms(500);                   //Delay 500 milliseconds
                }
                //Always make sure to close the file.
                FSfclose(myFile);
                
                //Just sit here until the device is removed.
                LCD_PutStr(1,0,"DONE!",TRUE);
                LCD_PutStr(2,0,"Safe to remove USB",FALSE);
                while(USBHostMSDSCSIMediaDetect()){ USBTasks();}

                RemoveChime();
                //Create a strings for the LCD//
                LCD_PutStr(1,0,"Aguijon USB MSD",TRUE);
                LCD_PutStr(2,0,"Insert flash drive",FALSE);
            }
        }
    }
    return 0;
}
