/********************************************************************
 FileName:    	CoreTimer.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
  CoreTimer  Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/

#if defined(XC16)
    #include "xc.h" // to have acces to timer peripherals
#endif

union
{
    unsigned long int val;     //32-bit value
    struct
    {
        unsigned short int LW; //16 LSb
        unsigned short int HW; //16 MSb
    } word;
}timercount;

static int initialized = 0;

//----------------------------------------------------------------------------

static void prvinit_core_timer(void)
{
//To configure the timer 2/3 for 32-bit operation:
// 1. Set the T32 bit (T2CON<3> or T4CON<3> = 1).
    T2CONbits.T32 = 1;
// 2. Select the prescaler ratio for Timer2 or Timer4 using the TCKPS<1:0> bits.
    T2CONbits.TCKPS = 0; //1:1 scale
// 3. Set the Clock and Gating modes using the TCS and TGATE bits. If TCS is set
//   to external clock, RPINRx (TxCK) must be configured to an available RPn pin.
    //Clock pin is not used
// 4. Load the timer period value. PR3 (or PR5) will contain the most significant
//   word of the value while PR2 (or PR4) contains the least significant word.
    PR2 = 0xFFFF;
    PR3 = 0xFFFF; //this is count up to 2^32 (4.29e9) clock pulses
// 5. If interrupts are required, set the interrupt enable bit, T3IE or T5IE; use
//   the priority bits, T3IP<2:0> or T5IP<2:0>, to set the interrupt priority.
    //Interruprs are not used
// 6. Set the TON bit (= 1).
    T2CONbits.TON = 1; //start the timer
}

//----------------------------------------------------------------------------

unsigned long int ReadCoreTimer(void)
{
    if(!initialized)
    {
        prvinit_core_timer();
        initialized = 1;
    }
    timercount.word.HW = TMR3;
    timercount.word.LW = TMR2;
    
    return (unsigned long int) timercount.val;
}

