/********************************************************************
 FileName:    	irDA.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    irDA  Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/

#include "aguijon.h"
#include "CoreTimer.h"
#include "uart.h"
#include "irDA.h"
#include "PPS.h"

///////////////////////////////////////////////////////
static boton_type buttons_array[MAX_DIFERENT_BUTTONS];

unsigned char  rxbuf[MAX_BUTTON_ARRAY_SIZE]; // data received
unsigned int   rxlen= 0;                    // length of the received data

static UINT32  tick = 0x00000000;
//////////////////////////////////////////////////////

void IR_init(void)
{
    PPSUnLock;  //Unlock PPS register
    RPINR18bits.U1RXR = 14; //assign U1RX to RP14
    PPSLock;    //lock PPS register

    CloseUART1();

    IFS0bits.U1RXIF   = 0;
    IEC0bits.U1RXIE   = 1;      //enable only RX interrupt
    IPC2bits.U1RXIP2  = 0;
    IPC2bits.U1RXIP1  = 1;
    IPC2bits.U1RXIP0  = 0;

    U1MODE = 0x9000;    //irDA enable, low baudrate, 8bit comm, no parity, 1 stop bit
    U2STA = 0x240;
    U1BRG = 832;        //Set 1200 baud
}


void IR_reception (void)
{

    int irrxData;

    irrxData=ReadUART1();   //get received data

    if(ReadCoreTimer()-tick > TimeOut)
    rxlen=0;

    if(rxlen<MAX_BUTTON_ARRAY_SIZE)
    {
        rxbuf[rxlen]=irrxData;
        rxlen++;
    }
    tick=ReadCoreTimer();
}


int Button_compare (void)
{
    int i=0 , j=0 , pressed=0;

	//search for a match trough all the button entries
	for (i=0;i<MAX_DIFERENT_BUTTONS;i++) //for each entry on button array
	{
            // compare one byte at a time until completion or abortion
            for (j=0;j<MAX_BUTTON_ARRAY_SIZE;j++)
            {
                // if any byte doesn't match, quit and try next button
                if(buttons_array[i].data[j] != rxbuf[j])
                {
                    break;
                }
                // the comparation is a perfect match, this is the button
                if((j+1) == MAX_BUTTON_ARRAY_SIZE)
                {
                    pressed=i+1;
                    break;
                }
            }
	}
        return pressed;
}


void Button_Config (int num)
{
    int i;
    if(num>10 || !num)
        return;

    for(i=0;i<MAX_BUTTON_ARRAY_SIZE;i++)
    {
        buttons_array[num-1].data[i]=rxbuf[i];
    }
}


void __attribute__((interrupt,__no_auto_psv__)) _U1RXInterrupt(void)
{
    IR_reception();
    LED1_SET = !LED1_SET;   //toggle LED1 using the global macro
    IFS0bits.U1RXIF = 0;    //clear the interrupt status of UART1 RX
}

