/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 27 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support
#include "irDA.h"               //irDA support

///////////////////////////////////////

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

    /*irDA*/
    IR_init();

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////

int main(void)
{
    unsigned int i;
    char lcdMSG[20];

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 27",FALSE);
    delayms(1000);

    for(;;){
        
        for(i=1;i<=5;i++)       //Configure Buttons from 1 to 5
        {
            //Create a strings for the LCD//
            sprintf(lcdMSG,"Press Button %i ",i);
            LCD_PutStr(1,0,lcdMSG,TRUE);

            while (SW_Read() !=1) {} //Just sit here until the button is pressed
            Button_Config(i);        //Configure Button
        }

        for(;;)
        {
            if(Button_compare()==1)     //If button 1 is pressed, Then
                LEDport_Set(3,ON);      //Show 3 in LEDport
            if(Button_compare()==2)     //If button 2 is pressed, Then..
                LEDport_Set(12,ON);
            if(Button_compare()==3)     //If button 3 is pressed, Then..
                LEDport_Set(48,ON);
            if(Button_compare()==4)     //If button 4 is pressed, Then..
                LEDport_Set(192,ON);
            if(Button_compare()==5)     //If button 5 is pressed, Then..
                LEDport_Set(255,ON);

            //Create a strings for the LCD//
            sprintf(lcdMSG,"Button %i       ",Button_compare());
            LCD_PutStr(1,0,lcdMSG,FALSE);
        }
    }
    return 0;
}
