/********************************************************************
 FileName:    	MCP23S17.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Low level General Purpose Input / Output + i2c & SPI Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/

#include "aguijon.h"
#include "MCP23S17.h"
#include "IO.h"

static void writeMCP23S17(int address,int data1,int data2);

void MCP23S17_Init(void)
{

    IO_SPIinit();

    LATDbits.LATD4 = 1; //Disable Chip Select
    delayms(10);    //wait for the expander

    writeMCP23S17(IOCON_reg,0x40,0xC0);      //config register addresses as sequential 0x40

    writeMCP23S17(IODIR_reg,0x00,0x00);      //PORTA -> outputs | PORTB-> inputs
    writeMCP23S17(OLAT_reg, 0x00,0x00);      //output latch register
    writeMCP23S17(GPPU_reg, 0x00,0x00);      //pull up register disabled
    writeMCP23S17(GPIO_reg, 0xFF,0xFF);      //even if we wrote, we wouldn't see a change
}


void MCP23S17_PortsConfig(BOOL Port, unsigned char direction)
{
    //writes to IODIR register, thus changing the port's bits state
    // 0->output | 1->input

    unsigned char PORTAdata = 0;
    unsigned char PORTBdata = 0;

    if(Port){         //if this is true, we will write the mask to PORTA
        PORTAdata &= direction;
    }else{                  //if not, the data will be written to PORTB
        PORTBdata &= direction;
    }

    writeMCP23S17(IODIR_reg,PORTAdata,PORTBdata);
}

void MCP23S17_Write(int data_a,int data_b)
{
    LATDbits.LATD4 = 0;     //Enable Chip Select
    IO_SPIsendByte(MCP_WRITE);
    IO_SPIsendByte(GPIOA_ADDRESS);
    IO_SPIsendByte(data_a);
    IO_SPIsendByte(data_b);
    LATDbits.LATD4 = 1;     //Disable Chip Select
}


unsigned char MCP23S17_Read(BOOL port)
{
    unsigned char portAdata = 0;
    unsigned char portBdata = 0;

    SPI1_CS = 0;     //Enable Chip Select
    IO_SPIsendByte(MCP_WRITE);
    IO_SPIsendByte(GPIOA_ADDRESS);
    IO_SPIsendByte(0);
    IO_SPIsendByte(0);
    SPI1_CS = 1;     //Disable Chip Select

   SPI1_CS = 0;      //Enable Chip Select
   IO_SPIsendByte(MCP_READ);
   IO_SPIsendByte(GPIOA_ADDRESS);
   portAdata = IO_SPIreadByte();
   portBdata = IO_SPIreadByte();
   SPI1_CS = 1;      //Disable Chip Select

   if(port){
       return portAdata;
   }else{
       return portBdata;
   }
}


static void writeMCP23S17(int address,int data1,int data2)
{
    SPI1_CS = 0;     //Enable Chip Select
    IO_SPIsendByte(MCP_WRITE);
    IO_SPIsendByte(address);
    IO_SPIsendByte(data1);
    IO_SPIsendByte(data2);
    SPI1_CS = 1;     //Disable Chip Select
}
