/********************************************************************
 FileName:    	MCP23S17.H
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Low level General Purpose Input / Output + i2c & SPI Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/

/*
 * The MCP23S17 is configured via software to automatically toggle the
 * register's pointer address, so we only write the register address once,
 * for instance, we write IODIRA, and the pointer will toggle automatically
 * to IODIRB.
 */

#define IODIR_reg       0x00    // Direction register            [ 1=input  / 0=output   ]
#define IPOL_reg        0x02    // Input polarity                [ 0=same   / 1=opposite ]
#define GPINTEN_reg     0x04    // Interrupt register            [ 1=enable / 0=disable  ]
#define DEFVAL_reg      0x06    // default compare value
#define INTCON_reg      0x08    // interrupt on change control
#define IOCON_reg       0x0A    // IO expander config register
#define GPPU_reg        0x0C    // Pull up resistor register     [ 1=pullup enable / 0=pullup disable ]
#define INTF_reg        0x0E    // interrupt flag register
#define INTCAP_reg      0x10    // interrupt captured value
#define GPIO_reg        0x12    // General purpose IO register
#define OLAT_reg        0x14    // Output latch register         [ 1=logic_high / 0=logic_low ]

#define MCP_READ        0x41    //Address to Read
#define MCP_WRITE       0x40    //Address to Write

#define PORT_A          TRUE    //Macros PORTA
#define PORT_B          FALSE   //Macros PORTB
#define GPIOA_ADDRESS   0x12    //GPIOA Address


void MCP23S17_Init          (void);
void MCP23S17_PortsConfig   (BOOL Port, unsigned char direction);
void MCP23S17_Write         (int data_a,int data_b);
unsigned char MCP23S17_Read (BOOL port);

