/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 30

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             RASH

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "IO.h"                 //IO support
#include "inputs.h"             //inputs support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "RS232.h"              //RS232 support
#include "analog.h"             //analog support



///////////////////////////////////////
void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*ADC*/
    ADC_Init();

    /*LCD*/
    LCD_Init(OFF);

    /*PWM*/
    OC_PWMChannelConfig(1);   // Set the PWM to Use


#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif

    LEDport_Set(0xFF,OFF);

}

///////////////////////////////////////


int main(void)
{
    /* Variable Declaration */
    double frequency    = 0.0;
    double finalPeriod  = 0.0;
    char lcdMSG1[20] , lcdMSG2[20];
    int period = 0;
    int duty_cycle = 50;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",ON);
    LCD_PutStr(2,0,"Application Note 30",OFF);
    delayms(1000);
    LCD_Clear();

    for(;;){



            period = ADC_Range(100,1000);               // Read ADC witch a range of 100 - 1000

            OC_PWMSet(period,duty_cycle);               // Variable period and 50% duty

            finalPeriod = (double) (period);

            frequency = (1000000 / finalPeriod);        // Formula for Frequency

            // Create the string for lcdMSG1
            sprintf(lcdMSG1,"Period: %d", period);
            LCD_PutStr(1,0,lcdMSG1,ON);

            // Create the string for lcdMSG2
            sprintf(lcdMSG2,"Frequency: %.2f", frequency);
            LCD_PutStr(2,0,lcdMSG2,OFF);
  
            delayms(150);                              // Delay 150 milliseconds


    }

    return 0;
}
