/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 31 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support
#include "InputCapture.h"       //Input Capture

///////////////////////////////////////


void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

    /*PWM*/
    OC_PWMChannelConfig(1); //Assigns PWM to open collector output #1

    /*Input Capture*/
    InputCapture_Init();

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////

int main(void)
{
    unsigned int value=0;
    char lcdMSG1[20] , lcdMSG2[20];
    UINT32 period=0, frequency=0;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 31",FALSE);
    delayms(1000);

    for(;;){

        value=ADC_Range(5,1000);        //Read ADC Range of 5 to 1000

        OC_PWMSet(value,50);            //Variable period and 50% duty

        period=Input_Period();          //Read Period

        frequency=Input_Frequency();    //Read Frequency

        //Create a first string for the LCD//
        sprintf(lcdMSG1,"Period= %i %lu",value,period);
        LCD_PutStr(1,0,lcdMSG1,TRUE);

        //Create a second string for the LCD//
        sprintf(lcdMSG2,"Frequency= %luHz",frequency);
        LCD_PutStr(2,0,lcdMSG2,FALSE);

        delayms(150);                   //Delay 150 milliseconds
        
    }
    return 0;
}
