/********************************************************************
 FileName:    	Interrupts.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Interrupts Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "ports.h"
#include "Interrupts.h"
#include "CoreTimer.h"
#include <PPS.h>

static UINT32  tick = 0x00000000;
static UINT32  cycle_time = 0x00000001;
///////////////////////////////////////

void Interrupts_Init (void)
{
    AD1PCFG = ADC_PIN_MASK;             // Turn Off All Analogs Channels
    INTCON1 = 0x0000;
    INTCON2 = 0x0002;

    INTCON2bits.INT1EP=1;

    TRISBbits.TRISB1  = 1;        // Configure RP1 as Input

    PPSUnLock;                    // Unlock remmapable pins
    iPPSInput(IN_FN_PPS_INT1, IN_PIN_PPS_RPI33);    // Set RP1 to External Interrupt 1
    PPSLock;                      // Lock remmapable pins

    CloseINT1();
    ConfigINT1( INT_ENABLE & FALLING_EDGE_INT & INT_PRI_2 );
}

void __attribute__((__interrupt__, auto_psv )) _ISR _INT1Interrupt (void)
{
    /* Configuration Before ISR Starts */
    IFS1bits.INT1IF  = 0;        // Clear Status Bit
    IEC1bits.INT1IE  = 0;        // Disable INIT1

    cycle_time=(ReadCoreTimer()-tick);
    tick=ReadCoreTimer();

    /* Configuration After ISR Finish */
    IFS1bits.INT1IF  = 0;       // Clear Status Bits
    IEC1bits.INT1IE  = 1;       // Enable INIT1
}

float AC_Frequency (void)
{
    float frequency   = 0.0;
    float cycles      = 0.0;

    cycles=cycle_time;

    frequency=(FCY/cycles);

    return frequency;
}
