/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 33 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support
#include "timers.h"             //Timers support
#include "outcompare.h"         //Outcompare support

///////////////////////////////////////

unsigned int duty_value=0;

/* Duty value for  0 10 20 30 40 50 60 70 80  90 100 110 120 130 140 150 160 170*/
/*                180 190 200 210 220 230 240 250 260  270 280 290 300 310 320 330 340 350 */
int Duty [36]={50, 58, 67, 75, 82, 88, 93, 97, 98, 99, 98, 97, 93, 88, 82, 75, 67, 58,
                   50, 41, 32, 25, 18, 11,  6,  3,  2,  1,  2,  3,  6, 11, 18, 25, 32, 41 };

void __attribute__((__interrupt__, __shadow__,__no_auto_psv__)) _T1Interrupt(void)
{

    /*Configure PWM*/
    CloseOC3();
    OpenOC3(0x1C00 | 0x0005, 0x001f ,100, Duty[duty_value]);

    duty_value++;
    if(duty_value==35)
        duty_value=0;

    IFS0bits.T1IF = 0; //Reset Timer1 interrupt flag and Return from ISR
}

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

    /*PWM*/
    OC_PWMChannelConfig(4);     //assigns PWM to open collector output #1

    /*Timer*/
    Timer1_Init();


#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////

int main(void)
{
    char   lcdMSG[20];
    double Frequency=0;
    int    timer_tick=0;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 33",FALSE);
    delayms(1000);

    Timer1_Enable();

    for(;;){

        timer_tick=ADC_Range(45,500);       //Read ADC range of 45 to 500

        Timer1_SetTick(timer_tick);         //SetTick of Timer 1

        Frequency=1/(timer_tick*.000144);   //Calculate Frequency

        /*Create a string for the LCD*/
        sprintf(lcdMSG,"Frequency= %.2fHZ",Frequency);
        LCD_PutStr(1,6,"Sine wave",TRUE);
        LCD_PutStr(2,0,lcdMSG,FALSE);

        delayms(100);       //Delay 100 milliseconds
    }
    return 0;
}