/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 34 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support
#include "timers.h"             //Timers support
#include "servomotor.h"         //Servomotor support


void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

    /*Servomotor*/
    SERVO_Init();
    SERVO_Config(1);
    SERVO_Config(2);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////

int main(void)
{
    int i=0 , j=0 ;
    char lcdMSG[20];

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 34",FALSE);
    delayms(1000);

    for(;;){

        /* 'i' increases from 0 to 180, while 'j' decreases 180 to 0 */
        for(i=0,j=180 ; i<=180 ; i++,j--)
        {
            SERVO_Set(1,i);         //Move servo 1
            SERVO_Set(2,j);         //Move servo 2

            /*Create a string for the LCD*/
            sprintf(lcdMSG,"Serv1=%3i  Serv2=%3i",i,j);
            LCD_PutStr(1,0,lcdMSG,TRUE);

            delayms(30);            //Delay 30 Milliseconds
        }
        
        /* 'i' decreases from 180 to 0, while 'j' increases 0 to 180 */
        for(i=180,j=0 ; i>=0 ; i--,j++)
        {
            SERVO_Set(1,i);         //Move servo 1
            SERVO_Set(2,j);         //Move servo 2

            /*Create a string for the LCD*/
            sprintf(lcdMSG,"Serv1=%3i  Serv2=%3i",i,j);
            LCD_PutStr(1,0,lcdMSG,TRUE);                    

            delayms(30);            //Delay 30 Milliseconds
        }
    }
    return 0;
}
