/********************************************************************
 FileName:    	Servomotor.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Servomotor Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#define USE_AND_OR
#define ocmp_v2_3
#include "aguijon.h"
#include "servomotor.h"
#include "outputs.h"
#include <outcompare.h>
#include <PPS.h>

///////////////////////////////////////
void SERVO_Init(void)
{
    T2CON = 0x0010;             //Stops the Timer2 and reset control reg. 1:8 ps
    TMR2  = 0x00; 		//Clear contents of the timer registers

    IPC0bits.T1IP = 0x02; 	//Setup Timer2 interrupt for desired priority level
    IFS0bits.T2IF = 0; 		//Clear the Timer2 interrupt status flag
    IEC0bits.T2IE = 0; 		//Disable Timer2 interrupts

    PR2 = 1;                    //Load the Period register with 1.

    T2CONbits.TON = 1;  //Start Timer2
}

void SERVO_Config(unsigned char num)
{
    PPSUnLock;      //unlock remappable pins

    switch (num)
    {
        case 1:
            EXP_PORT2_PIN3_RPOUT  = 21;  //assign PWM4 (OC4) to RP14
            ConfigIntOC4(OC_INT_OFF);   //no interrupt
            break;
        case 2:
            EXP_PORT2_PIN4_RPOUT  = 22;  //assign PWM5 (OC5) to RP25
            ConfigIntOC5(OC_INT_OFF);   //no interrupt
            break;
        case 3:
            EXP_PORT2_PIN5_RPOUT  = 23;  //assign PWM6 (OC6) to RP20
            ConfigIntOC6(OC_INT_OFF);   //no interrupt
            break;
        case 4:
            EXP_PORT2_PIN6_RPOUT  = 24;  //assign PWM7 (OC7) to RP0
            ConfigIntOC7(OC_INT_OFF);   //no interrupt
            break;
        case 5:
            EXP_PORT2_PIN9_RPOUT  = 25;  //assign PWM8 (OC8) to RP1
            ConfigIntOC8(OC_INT_OFF);   //no interrupt
            break;
        case 6:
            EXP_PORT2_PIN10_RPOUT  = 35;  //assign PWM9 (OC9) to RP13
            ConfigIntOC9(OC_INT_OFF);   //no interrupt
            break;
    }

    PPSLock;                    //lock remappable pins
}

void SERVO_Set (unsigned char num , unsigned int degrees)
{
    UINT16 servo_fixedDuty   = 0;

    if(degrees <= 180){
        servo_fixedDuty  = (int) ((180-degrees) * DEGREES_CONV_FACTOR);
        servo_fixedDuty += START_POSITION;
    }
    else{
        servo_fixedDuty  = 2900;
    }

    switch (num)
    {
        case 1:
            CloseOC4();
            OpenOC4(OC_TIMER2_SRC | OC_CONTINUE_PULSE, OC_SYNC_TRIG_IN_CURR_OC, SERVO_PERIOD, servo_fixedDuty);
            break;
        case 2:
            CloseOC5();
            OpenOC5(OC_TIMER2_SRC | OC_CONTINUE_PULSE, OC_SYNC_TRIG_IN_CURR_OC, SERVO_PERIOD, servo_fixedDuty);
            break;
        case 3:
            CloseOC6();
            OpenOC6(OC_TIMER2_SRC | OC_CONTINUE_PULSE, OC_SYNC_TRIG_IN_CURR_OC, SERVO_PERIOD, servo_fixedDuty);
            break;
        case 4:
            CloseOC7();
            OpenOC7(OC_TIMER2_SRC | OC_CONTINUE_PULSE, OC_SYNC_TRIG_IN_CURR_OC, SERVO_PERIOD, servo_fixedDuty);
            break;
        case 5:
            CloseOC8();
            OpenOC8(OC_TIMER2_SRC | OC_CONTINUE_PULSE, OC_SYNC_TRIG_IN_CURR_OC, SERVO_PERIOD, servo_fixedDuty);
            break;
        case 6:
            CloseOC9();
            OpenOC9(OC_TIMER2_SRC | OC_CONTINUE_PULSE, OC_SYNC_TRIG_IN_CURR_OC, SERVO_PERIOD, servo_fixedDuty);
            break;
    }
}
