/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrón Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 35 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "EEPROM.h"             //EEPROM support
#include "IO.h"                 //IO support
#include "inputs.h"             //inputs support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "realtime.h"           //RTCC module support
#include "RS232.h"              //RS232 support
#include "timers.h"             //timers support
#include "make_wav.h"           //Make_wav support

//USB
#include "USB/usb.h"
#include "USB/usb_host_msd.h"
#include "USB/usb_host_msd_scsi.h"
#include "MDD File System/FSIO.h"

#define S_RATE  (8000)
#define BUF_SIZE (1024)
#define MAX_SAMPLE_VALUE 30000
#define MIN_SAMPLE_VALUE -30000

/*state 0 is empty, state 1 is full*/
BOOL state_a=0;
BOOL state_b=1;
BOOL Write=0;

 int buffer_a[BUF_SIZE];
 int buffer_b[BUF_SIZE];

 int sample=0;
 int  num_sample=0;
///////////////////////////////////////

void __attribute__((__interrupt__, __shadow__,__no_auto_psv__)) _T1Interrupt(void)
{

sample=((ADC_Read()*110)-95000);
    if(sample>MAX_SAMPLE_VALUE || sample<MIN_SAMPLE_VALUE)
        sample=0;


    if(!state_a)
        buffer_a[num_sample]=sample;
    if(!state_b)
        buffer_b[num_sample]=sample;

    num_sample++;

    if(num_sample==BUF_SIZE)
    {
        state_a=!state_a;
        state_b=!state_b;
        num_sample=0;
        Write=1;
    }


    IFS0bits.T1IF = 0; //Reset Timer1 interrupt flag and Return from ISR
}

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    DIPSW_Config(DIPSW_DISABLE_CMD);
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

    /*Timer1*/
    Timer1_Init();
    Timer1_SetTick(2000);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif

    LEDport_Set(0,ON);
}

void InsertChime(void)
{
    delayms(100);
    Buzzer_On(800,50);
    delayms(30);
    Buzzer_Off();
    delayms(80);
    Buzzer_On(421,50);
    delayms(30);
    Buzzer_Off();
}

void RemoveChime(void)
{
    delayms(100);
    Buzzer_On(421,50);
    delayms(30);
    Buzzer_Off();
    delayms(80);
    Buzzer_On(800,50);
    delayms(30);
    Buzzer_Off();
}

///////////////////////////////////////


int main(void)
{

    HammerHead_Init();  //initialize [VD]HammerHead
    USBInitialize(0);   //Initialize the stack
    USB_5V_ENABLE = 0;  //Turn 5V USB output on

    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Aguijon USB MSD",TRUE);
    LCD_PutStr(2,0,"Insert flash drive",FALSE);

    for(;;){
        //USB stack process function
        USBTasks();

        //if thumbdrive is plugged in
        if(USBHostMSDSCSIMediaDetect()){
        InsertChime();
        //now a device is attached

            //See if the device is attached and in the right format
            if(FSInit()){

                /*Create a string for the LCD*/
                LCD_PutStr(1,0,"Digital Recorder  ",FALSE);
                LCD_PutStr(2,0,"REC               ",FALSE);

                while(SW_Read()!=1);
                /*Create a string for the LCD*/
                LCD_PutStr(1,0,"Recording..        ",FALSE);
                LCD_PutStr(2,0,"STOP ",FALSE);

                //Opening a wav file in mode "w" will create the file if it doesn't
                //  exist.  If the file does exist it will delete the old file
                //  and create a new one that is blank.
                WAV_Init("test.wav", S_RATE);

                Timer1_Enable();        //Timer 1 eneable
                while(SW_Read() !=1)
                {
                    if(state_a && Write)
                    {
                        WAV_Add(buffer_a,sizeof (buffer_a));        //Add samples to the file
                        Write=0;
                    }
                    if(state_b && Write)
                    {
                        WAV_Add(buffer_b,sizeof (buffer_b));        //Add samples to the file
                        Write=0;
                    }
                }
                Timer1_Disable();        //Timer 1 disable

                WAV_Close();        //Closing a wav file

                /*Create a string for the LCD*/
                LCD_PutStr(1,0,"DONE!",TRUE);
                LCD_PutStr(2,0,"Safe to remove USB",FALSE);

                //Just sit here until the device is removed.
                while(USBHostMSDSCSIMediaDetect()){
                    USBTasks();
                }
                /*Create a string for the LCD*/
                LCD_PutStr(1,0,"Aguijon USB MSD",TRUE);
                LCD_PutStr(2,0,"Insert flash drive",FALSE);
            }
        }
    }
    return 0;
}