/********************************************************************
 FileName:    	make_wav.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagr�n Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    make_wav Support File


 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#define USE_AND_OR
#define ocmp_v2_3
#include "aguijon.h"
#include "outputs.h"
#include "make_wav.h"
#include <assert.h>

#include "MDD File System/FSIO.h"

FSFILE* wav_file;
static UINT32 samples=0;

void write_little_endian(UINT32 word, int num_bytes, FSFILE *wav_file)
{
    unsigned buf;
    while(num_bytes>0)
    {   buf = word & 0xff;
        FSfwrite(&buf, 1,1, wav_file);
        num_bytes--;
    word >>= 8;
    }
}

                                ///unsigned long
void WAV_Init(char * filename,int s_rate)
{
    unsigned int byte_rate;

    byte_rate = s_rate*BYTES_PER_SAMPLE;

    wav_file = FSfopen(filename, "w");
    assert(wav_file);   /* make sure it opened */

    /* write RIFF header */
    FSfwrite("RIFF", 1, 4, wav_file);
    write_little_endian(0x00000000, 4, wav_file);
    FSfwrite("WAVE", 1, 4, wav_file);
 
    /* write fmt  subchunk */
    FSfwrite("fmt ", 1, 4, wav_file);
    write_little_endian(16, 4, wav_file);   /* SubChunk1Size is 16 */
    write_little_endian(1, 2, wav_file);    /* PCM is format 1 */
    write_little_endian(NUM_CHANNELS, 2, wav_file);
    write_little_endian(s_rate, 4, wav_file);
    write_little_endian(byte_rate, 4, wav_file);
    write_little_endian(NUM_CHANNELS*BYTES_PER_SAMPLE, 2, wav_file);  /* block align */
    write_little_endian(8*BYTES_PER_SAMPLE, 2, wav_file);  /* bits/sample */

    /* write data subchunk */
    FSfwrite("data", 1, 4, wav_file);
    write_little_endian(0x00000000, 4, wav_file);

}

void WAV_Add (unsigned int * data, unsigned int size)
{
    FSfwrite(data,1,size,wav_file);
    samples++;
}


void WAV_Close (void)
{
    FSfseek(wav_file,4,SEEK_SET);
    write_little_endian(36 + BYTES_PER_SAMPLE* samples*1024, 4, wav_file);
    FSfseek(wav_file,40,SEEK_SET);
    write_little_endian(BYTES_PER_SAMPLE* samples*1024, 4, wav_file);
    FSfclose(wav_file);
}

///////////////////////////////////////

