/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             RASH

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/

#include "aguijon.h"
#include "IO.h"
#include "matrix_keyboard.h"
#include "outputs.h"







/**************** Defined in matrix_keyboard.h  **********************/

char keyboard [5] [5] = { "     ",
                          "*0#D ",
                          "789C ",
                          "456B ",
                          "123A "};


#if defined (MATRIX_KEYBOARD_PORT1_J5)

void PORTX_SET_J5 (int value)
{
    PORT_J5_SET_PIN1 = 1^ (value & 0b00001);
    PORT_J5_SET_PIN2 = 1^((value & 0b00010)>>1);
    PORT_J5_SET_PIN3 = 1^((value & 0b00100)>>2);
    PORT_J5_SET_PIN4 = 1^((value & 0b01000)>>3);
    PORT_J5_SET_PIN5 = 1^((value & 0b10000)>>4);
}

unsigned char PORTX_GET_J5 (void)
{
    unsigned char x = 0;


    x = (!PORT_J5_GET_PIN1) ? 0b00001 : x;
    x = (!PORT_J5_GET_PIN2) ? 0b00010 : x;
    x = (!PORT_J5_GET_PIN3) ? 0b00011 : x;
    x = (!PORT_J5_GET_PIN4) ? 0b00100 : x;
    x = (!PORT_J5_GET_PIN5) ? 0b00101 : x;

    return x;
}

unsigned char Check_Value_Keyboard_J5 (void)
{

    int i , j , x;
    unsigned char result = 0;
    
    for(i=1, j=0 ;i<=16;i<<=1 , j++)
    {
        PORTX_SET_J5(i);
        x = PORTX_GET_J5();
        if(x)
        {
            result=keyboard[x][j];
            delayms(1);
            return result;
        }
    }

    return FALSE;
}

unsigned char Matrix_Keyboard_Read_J5 (void)
{
    /* This function will only read 1 value when you pressed and it will return FALSE */

     unsigned char pressedKey   = 0;
     static unsigned char lastPressed  = 0;


     pressedKey = Check_Value_Keyboard_J5();


    if(pressedKey != lastPressed){

        lastPressed = pressedKey;

        return pressedKey;

    }

    return FALSE;
}


unsigned char Matrix_Keyboard_ReadPort_J5 (void)
{
    /* This function will read constantly the value of the keyboard */

    static unsigned char pressedKey   = 0;

    pressedKey = Check_Value_Keyboard_J5();

    if(pressedKey){
        return pressedKey;
    }

    return FALSE;
}



#endif






#if defined (MATRIX_KEYBOARD_PORT2_J6)


void PORTX_SET_J6 (int value)
{
    PORT_J6_SET_PIN1 = 1^ (value & 0b00001);
    PORT_J6_SET_PIN2 = 1^((value & 0b00010)>>1);
    PORT_J6_SET_PIN3 = 1^((value & 0b00100)>>2);
    PORT_J6_SET_PIN4 = 1^((value & 0b01000)>>3);
    PORT_J6_SET_PIN5 = 1^((value & 0b10000)>>4);
}

unsigned char PORTX_GET_J6 (void)
{
    unsigned char x = 0;

    x = (!PORT_J6_GET_PIN1) ? 0b00001 : x;
    x = (!PORT_J6_GET_PIN2) ? 0b00010 : x;
    x = (!PORT_J6_GET_PIN3) ? 0b00011 : x;
    x = (!PORT_J6_GET_PIN4) ? 0b00100 : x;
    x = (!PORT_J6_GET_PIN5) ? 0b00101 : x;

    return x;
}

unsigned char Check_Value_Keyboard_J6 (void)
{
    int i , j , x;
    unsigned char result = 0;

    for(i=1, j=0 ;i<=16;i<<=1 , j++)
    {
        PORTX_SET_J6(i);
        x = PORTX_GET_J6();
        if(x)
        {
            result=(j*5) + x;
            delayms(1);
            return result;
        }
    }

    return FALSE;
}

unsigned char Matrix_Keyboard_Read_J6 (void)
{
    /* This function will only read 1 value when you pressed and it will return FALSE */

     unsigned char pressedKey   = 0;
     static unsigned char lastPressed  = 0;


     pressedKey = Check_Value_Keyboard_J6();


    if(pressedKey != lastPressed){

        lastPressed = pressedKey;

        return pressedKey;

    }

    return FALSE;
}


unsigned char Matrix_Keyboard_ReadPort_J6 (void)
{

    /* This function will read constantly the value of the keyboard */

    static unsigned char pressedKey   = 0;

    pressedKey = Check_Value_Keyboard_J6();

    if(pressedKey){
        return pressedKey;
    }

    return FALSE;
}





#endif





