/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 37 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support
#include "RS232.h"              //RS232 support
#include <string.h>             //string support
///////////////////////////////////////

#define EXIT input == '*'
void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

    /*RS232*/
    RS232_Init(BAUD19200);

    /*PWM*/
    OC_PWMChannelConfig(4);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////

int main(void)
{
    enum {HOME, RELAY, PWM, LCD, ADC, DIP} state=HOME;
    int  duty  = 50, relay = 0, strsize=0;
    char input =  0, rs232MSG[40], lcdMSG1[20], lcdMSG2[20], preletter[1], letter2[1];

    lcdMSG1[0] = '\0';

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 37",FALSE);

    RS232_PutStr((unsigned int *)"\rWelcome to Aguijon");

    for(;;){

        switch (state)  //Switch functions
        {
            /*HOME state*/
            case HOME:
                RS232_PutStr((unsigned int *)"\n\r--SELECT FUNCTION--");
                RS232_PutStr((unsigned int *)"\r1.- RELAY SET");
                RS232_PutStr((unsigned int *)"\r2.- PWM SET");
                RS232_PutStr((unsigned int *)"\r3.- LCD PUT STRING");
                RS232_PutStr((unsigned int *)"\r4.- READ ADC PORT");
                RS232_PutStr((unsigned int *)"\r5.- READ DIP SWITCH\n");

                input = RS232_Read();   //Read RS232
                if (input == '1') {
                    RS232_PutStr((unsigned int *)"\n\r--RELAY SET--\n");
                    RS232_PutStr((unsigned int *)"\rSELECT RELAY (1-4)");
                    RS232_PutStr((unsigned int *)"\rOR PRESS '*' TO EXIT\n");
                    state = RELAY;  /*Go to RELAY state*/
                }
                if (input == '2') {
                    RS232_PutStr((unsigned int *)"\n\r--PWM SET--\n");
                    RS232_PutStr((unsigned int *)"\rPRESS '+' TO INCREASE DUTY CYCLE AND '-' TO DECREASE");
                    RS232_PutStr((unsigned int *)"\rOR PRESS '*' TO EXIT\n");
                    state = PWM;  /*Go to PWM state*/
                }
                if (input == '3') {
                    RS232_PutStr((unsigned int *)"\r--LCD PUT STRING--\n");
                    RS232_PutStr((unsigned int *)"\rPUT YOUR TEXT HERE AND PRESS 'INTRO' TO CLEAR");
                    RS232_PutStr((unsigned int *)"\rOR PRESS '*' TO EXIT\n");
                    state = LCD;  /*Go to LCD state*/
                }
                if (input == '4') {
                    RS232_PutStr((unsigned int *)"\r--READ ADC PORT--\n");
                    RS232_PutStr((unsigned int *)"\rPRESS '(SPACE)' TO SHOW ADC VALUE");
                    RS232_PutStr((unsigned int *)"\rOR PRESS '*' TO EXIT\n");
                    state = ADC;  /*Go to ADC state*/
                }
                if (input == '5') {
                    RS232_PutStr((unsigned int *)"\r--READ DIP SWITCH--\n");
                    RS232_PutStr((unsigned int *)"\rPRESS '(SPACE)' TO SHOW DIP SWITCH VALUE");
                    RS232_PutStr((unsigned int *)"\rOR PRESS '*' TO EXIT\n");
                    state = DIP;  /*Go to DIP    state*/
                }
                break;

            /*RELAY state*/
            case RELAY:
                input=RS232_Read();   //Read RS232
                if(input == '1')
                    relay=1;
                if(input == '2')
                    relay=2;
                if(input == '3')
                    relay=3;
                if(input == '4')
                    relay=4;
                if(EXIT)
                    state = HOME; //Return to Home state
                if(input=='1' || input=='2' || input=='3' || input=='4')
                    RLY_Toggle(relay);

                if(RLY_Get(relay))
                    sprintf(rs232MSG,"\nRelay %i turn ON",relay);
                else
                    sprintf(rs232MSG,"\nRelay %i turn OFF",relay);
                RS232_PutStr((unsigned int*)rs232MSG);
                break;

            /*PWM state*/
            case PWM:
                input=RS232_Read();   //Read RS232

                if(input == '+')
                    duty += 5;
                if(input == '-')
                    duty -= 5;
                if(EXIT)
                    state = HOME; //Return to Home state
                OC_PWMSet(200,duty);
                sprintf(rs232MSG,"\rDUTY CYCLE=%i",duty);
                RS232_PutStr((unsigned int *)rs232MSG);
                break;

            /*LCD state*/
            case LCD:
                input = RS232_Read();   //Read RS232
                if(EXIT)
                    state=HOME; //Return to Home state

                if(input == 13 || input == 10)  //if press (intro)
                {
                    lcdMSG1[0] = '\0';
                    lcdMSG2[0] = '\0';
                    LCD_Clear();
                    strsize=0;
                }
                else {
                    sprintf(preletter,"%c",input);
                    sprintf(letter2,"%.1s",preletter);
                    if(strsize<20) {        //First line of LCD
                        strcat(lcdMSG1,letter2);
                        LCD_PutStr(1,0,lcdMSG1,TRUE);
                    }
                    if(strsize>=20 && strsize<40) { //Second line of LCD
                        strcat(lcdMSG2,letter2);
                        LCD_PutStr(2,0,lcdMSG2,FALSE);
                    }
                    strsize++;
                }
                break;

            /*ADC state*/
            case ADC:
                input = RS232_Read();   //Read RS232
                if(input == 32) {
                sprintf(rs232MSG,"\rADC VALUE=%i",ADC_Read());      //Read ADC
                RS232_PutStr((unsigned int *)rs232MSG);
                }
                if(EXIT)
                    state=HOME; //Return to Home state
                break;

            /*DIP satte*/
            case DIP:
                input = RS232_Read();   //Read RS232
                if(input == 32) {
                sprintf(rs232MSG,"\rDIP SWITCH VALUE=%i",DIPSW_Read()); //Read DIP-SW
                RS232_PutStr((unsigned int *)rs232MSG);
                }
                if(EXIT)
                    state=HOME; //Return to Home state
                break;

            default:
                state=HOME;
                break;
        }
    }
    return 0;
}