/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.
********************************************************************
 File Description:
    Main Application Note 38 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "RS232.h"              //RS232 support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support
#include "timers.h"             //Timers support
#include "realtime.h"           //RTCC support
#include "stopwatch.h"          //Stopwatch support

#define  ALARMS 3       //# of alarms

ALARM_CONTROL_t Alarm[ALARMS];

static unsigned char keyboard=0;
static unsigned int preday=0, prehour=0, premin=0;
char lcdMSG[20];
BOOL next = FALSE;

/*Read keyboard & adjust hour*/
void Config_hour(void)
{
    keyboard=SW_Read();

    if (keyboard == 1)
        prehour++;
    if (keyboard == 2)
        premin+=10;
    if (keyboard == 3)
        premin++;
    if (keyboard ==4)
        next = TRUE;
    if(prehour>=24)
        prehour=0;
    if(premin>=60)
        premin=0;

    sprintf(lcdMSG," %.2u : %.2u          OK",prehour,premin);
    LCD_PutStr(2,0,lcdMSG,FALSE);
}

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
    LCD_Init(LCD_MODE_1);

    /*RTCC*/
    RTCC_Init();

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}
///////////////////////////////////////

int main(void)
{
    enum {SET_DAY,SET_HOUR,SET_ALARM,SET_ALARMDAY,CLOCK} state=SET_DAY;
    char name_day [7] [10] = {"MONDAY","TUESDAY","WENSDAY","THURSDAY","FRIDAY","SATURDAY","SUNDAY"};
    int  alarm_num=0 , i=0;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 38",FALSE);
    delayms(1000);

    for(;;){

        switch (state)
        {
            /*Set week day*/
            case SET_DAY:
                //Create a string for the LCD//
                LCD_PutStr(1,0,"Today's Date",TRUE);

                keyboard=SW_Read();     //Read keyboard
                if(keyboard==1) {
                    preday++;
                    preday=(preday==7) ? 0 : preday;
                  }
                if(keyboard==4)
                    state=SET_HOUR;     //Go to SET HOUR state

                LCD_PutStr(2,0,name_day[preday],FALSE);
                LCD_PutStr(2,18,"OK",FALSE);
                break;

            /*Set Hours & Minutes*/
            case SET_HOUR:
                //Create a string for the LCD//
                LCD_PutStr(1,0,"Set Hour",TRUE);
                Config_hour();      //Read keyboard & adjust Hour
                if(next) {
                    next = FALSE;
                    TIME_Set(SET_WKDYHR,preday+1,prehour);
                    TIME_Set(SET_MINSEC,premin,00);
                    state=SET_ALARM;    //Go to SET ALARM state
                    RTCC_Enable();
                }
                break;

            /*Set  Alarm*/
            case SET_ALARM:
                //Create a string for the LCD//
                sprintf(lcdMSG,"Set alarm %i",alarm_num+1);
                LCD_PutStr(1,0,lcdMSG,TRUE);
                Config_hour();      //Read keyboard & adjust Hour
                if(next) {
                    Alarm[alarm_num].Hour = prehour;
                    Alarm[alarm_num].Min  = premin;
                    state=SET_ALARMDAY;     //Go to SET ALARMDAY state
                    next = FALSE;
                }
                break;

            /*Set days of Alarm*/
            case SET_ALARMDAY:
                //Create a string for the LCD//
                i++;
                if(i<20)
                    LCD_PutStr(1,0,"Select days with...",TRUE);
                else
                    LCD_PutStr(1,0,"Dip-sw & press  Here",TRUE);
                i = (i>40) ? 0 : i;
                LCD_PutStr(2,0,"Su Sa Fr Th We Tu Mo",FALSE);
                keyboard=SW_Read();

                LEDport_Set(DIPSW_Read(),ON);
                if(keyboard==4) {
                    Alarm[alarm_num].Days = DIPSW_Read();
                    alarm_num++;
                    state=(alarm_num==ALARMS) ? CLOCK : SET_ALARM;  //Go to SET ALARM or CLOCK state
                }
                break;
                
            /*Clock*/
            case CLOCK:
                //Create a string for the LCD//
                sprintf(lcdMSG,"%.2i:%.2i:%.2i",TIME_Get(GET_HOURS),TIME_Get(GET_MINUTES),TIME_Get(GET_SECONDS));
                LCD_PutStr(1,5,name_day[TIME_Get(GET_WEEKDAY)-1],TRUE);
                LCD_PutStr(2,5,lcdMSG,FALSE);

                /*if the current time is equal to the alarm*/
                for (alarm_num=0 ; alarm_num <ALARMS ; alarm_num++) {
                    if(((Alarm[alarm_num].Days>>(TIME_Get(GET_WEEKDAY)-1)) & 0b1)
                    &&  (Alarm[alarm_num].Hour == TIME_Get(GET_HOURS))
                    &&  (Alarm[alarm_num].Min == TIME_Get(GET_MINUTES))
                    &&  (TIME_Get(GET_SECONDS) < 5))
                    {
                        Alarm_actived();    //Alarm actived
                    }
                }
                break;
        }
        delayms(50);
    }
    return 0;
}
