/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0, rev4.0 & rev4.1
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application Note 39 file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             DIRD

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "IO.h"                 //IO support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "inputs.h"             //inputs support
#include "timers.h"             //inputs support
#include "waveform.h"           //waveform suport

void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports
    IO_PWMinit();     //initialize HammerHead PWMs

    /*Inputs*/
    ADC_Init();

    /*LCD*/
   LCD_Init(LCD_MODE_1);

   /*SPI*/
   IO_SPIinit();

   /*Timer*/
   Timer1_Init();
   Timer1_Enable();


#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif
    
    LEDport_Set(0,ON);
}

///////////////////////////////////////


int main(void)
{
    int keyboard=0;
    char lcdMSG[20];
    unsigned int input_frec = 1;

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();
    LCD_PutStr(1,0,"Vinagron Digital",TRUE);
    LCD_PutStr(2,0,"Application Note 39",FALSE);
    delayms(1000);
    LCD_Clear();

    for(;;){

        keyboard = SW_Read();

        switch (keyboard)
        {
            case 1:
                WAVE_Type(SINE);        //Set sine wave
                LCD_PutStr(1,0,"SINE WAVE",TRUE);
                break;
            case 2:
                WAVE_Type(TRIANGLE);    //Set triangle wave
                LCD_PutStr(1,0,"TRIANGLE WAVE",TRUE);
                break;
            case 3:
                WAVE_Type(RAMP);        //Set ramp wave
                LCD_PutStr(1,0,"RAMP WAVE",TRUE);
                break;
            case 4:
                WAVE_Type(SQUARE);      //Set square wave
                LCD_PutStr(1,0,"SQUARE WAVE",TRUE);
                break;
        }

        /*Set frequency from 0 to 1000 hz*/
        input_frec = ADC_Range(0,1000);
        WAVE_Frequency(input_frec);

        /*Create string for the LCD*/
        sprintf(lcdMSG,"%i HZ",input_frec);
        LCD_PutStr(2,0,lcdMSG,FALSE);

        delayms(5);
    }
    return 0;
}